@@ -3,13 +3,14 @@
 import sys
 import subprocess
 
-print "python:", sys.version.replace("\n", " ")
+print "python:", sys.version.replace("\n", " ") + ', maxunicode: ' + str(sys.maxunicode)
 
 try:
     out = subprocess.Popen(["buildbot", "--version"],
                            stdout=subprocess.PIPE).communicate()[0]
     print "buildbot:", out.replace("\n", " ")
-except EnvironmentError:
+except EnvironmentError, le:
+    sys.stderr.write("Got exception invoking 'buildbot': %s" % (le,))
     pass
 
 try:
@@ -20,7 +21,8 @@ try:
     print
     print "darcs:", out.replace("\n", " ")
     print full.rstrip()
-except EnvironmentError:
+except EnvironmentError, le:
+    sys.stderr.write("Got exception invoking 'darcs': %s" % (le,))
     pass
 
 try:
