@@ -1,7 +1,7 @@
 
 #include <Python.h>
 
-#include "publickey/ecdsamodule.hpp"
+//#include "publickey/ecdsamodule.hpp"
 #include "publickey/rsamodule.hpp"
 #include "hash/sha256module.hpp"
 #include "cipher/aesmodule.hpp"
@@ -10,7 +10,8 @@ PyDoc_STRVAR(_pycryptopp__doc__,
 "_pycryptopp -- Python wrappers for a few algorithms from Crypto++\n\
 \n\
 from pycryptopp import publickey\n\
-from pycryptopp.publickey import ecdsa, rsa\n\
+#from pycryptopp.publickey import ecdsa\n\
+from pycryptopp.publickey import rsa\n\
 from pycryptopp import cipher\n\
 from pycryptopp.cipher import aes\n\
 from pycryptopp import hash\n\
@@ -34,7 +35,7 @@ init_pycryptopp(void) {
     if (!module)
       return;
 
-    init_ecdsa(module);
+    //init_ecdsa(module);
     init_rsa(module);
     init_sha256(module);
     init_aes(module);
